/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#ifndef GEODE_INTERESTRESULTPOLICY_H_
#define GEODE_INTERESTRESULTPOLICY_H_

#include <cstdint>

namespace apache {
namespace geode {
namespace client {

/**
 * Policy class for interest result.
 *
 * Note: Special DataSeralizableFixedId(37) type.
 */
enum class InterestResultPolicy : int8_t {
  NONE = 0,
  KEYS = 1,
  KEYS_VALUES = 2
};

}  // namespace client
}  // namespace geode
}  // namespace apache

#endif  // GEODE_INTERESTRESULTPOLICY_H_
